Structs
- Chat
Completion Chunk - OpenAI-compatible streaming chunk
- Chat
Completion Message - OpenAI-compatible message in a chat completion request
- Chat
Completion Request - OpenAI-compatible chat completion request
- Chat
Completion Response - OpenAI-compatible chat completion response
- Choice
- A single choice in a chat completion response
- Chunk
Choice - A single choice in a streaming chunk
- Delta
- Delta content in a streaming chunk
- Error
Detail - Error detail within an
OpenAIerror response - Error
Response - OpenAI-compatible error response
- Function
Object - A function definition within a tool
- Health
Response - Response for GET /health
- Image
UrlDetail - Image URL details within a content part
- Json
Schema Spec - JSON schema specification within a response format request
- Model
Object - A single model entry in the models list
- Models
Response - Response for GET /v1/models
- Multiplex
Provider Result - Result from a single provider in a multiplex request
- Multiplex
Response - Response for multiplex requests (multiple providers)
- Response
Message - Message in a chat completion response
- Tool
Call - A tool call issued by the assistant
- Tool
Call Function - Function call details within a tool call
- Tool
Choice Function - Function name within a specific tool choice
- Tool
Choice Specific - A specific tool choice forcing a particular function
- Tool
Definition - A tool definition in the
OpenAIformat - Usage
- Token usage statistics
Enums
- Content
Part - A single content part within a multipart message
- Message
Content - Message content that can be either a plain string or an array of content parts
- Model
Field - A model field that can be either a single string or an array of strings
- Response
Format Request - OpenAI-compatible response format request
- Stop
Field - Stop field that accepts either a single string or an array of strings
- Tool
Choice - Controls which tools the model may call