pub type SharedState = Arc<RwLock<ServerState>>;Expand description
Type alias for the shared state handle used across the server
Aliased Type
pub struct SharedState { /* private fields */ }pub type SharedState = Arc<RwLock<ServerState>>;Type alias for the shared state handle used across the server
pub struct SharedState { /* private fields */ }