pub enum StopField {
Single(String),
Multiple(Vec<String>),
}Expand description
Stop field that accepts either a single string or an array of strings
Per OpenAI spec, the stop parameter can be a string or an array of
up to 4 strings.
Variants
Implementations